#!/bin/sh
#
# Called from udev
# Attemp to mount any added block devices 
# and remove any removed devices
#

MOUNT="/bin/mount"
PMOUNT="/usr/bin/pmount"
UMOUNT="/bin/umount"
name="`basename "$DEVNAME"`"
MOUNT_FLASH_CMD="$MOUNT -t auto -o rw,relatime,sync,fmask=0000,dmask=0000,iocharset=koi8-r,shortname=mixed,errors=remount-ro /dev/$name /media/$name"

FLASHCARD=0
for line in `cat /etc/udev/flashcard.list | grep -v ^#`
do
	if [ "$DEVNAME" = "/dev/${line}1" ] || [ "$DEVNAME" = "/dev/${line}2" ]\
        || [ "$DEVNAME" = "/dev/${line}3" ] || [ "$DEVNAME" = "/dev/${line}4" ]
	then
		FLASHCARD=1
	fi
done
if [ $FLASHCARD -eq 0 ]; then
	exit 0
fi


mount_flash() {
       ! test -d "/media/$name" && mkdir -p "/media/$name"                     
        
        EXIT_CODE=`$MOUNT_FLASH_CMD; echo $?`                                                                        
        if [ $EXIT_CODE -ne 0 ]                                                         
        then   
                source /tmp/user/dbus.env 
                su -c "dbus-send --type=signal / b5.flash.mountFailed \
                int32:$EXIT_CODE " user
                #logger "mount.sh/automount" "$MOUNT -t auto $DEVNAME \"/media/$
                rm_dir "/media/$name"                                           
                exit 0
        else                                                                    
                logger "mount.sh/automount" "Auto-mount of [/media/$name] successful"
                touch "/tmp/.automount-$name"                                   
        fi                                                                      
}
	
rm_dir() {
	# We do not want to rm -r populated directories
	if test "`find "$1" | wc -l | tr -d " "`" -lt 2 -a -d "$1"
	then
		! test -z "$1" && rm -r "$1"
	else
		logger "mount.sh/automount" "Not removing non-empty directory [$1]"
	fi
}

if [ "$ACTION" = "add" ] && [ -n "$DEVNAME" ]; then
	if [ -x "$PMOUNT" ]; then
		$PMOUNT $DEVNAME 2> /dev/null
	elif [ -x $MOUNT ]; then
    		$MOUNT $DEVNAME 2> /dev/null
	fi
	
	# If the device isn't mounted at this point, it isn't configured in fstab
	# 20061107: Small correction: The rootfs partition may be called just "rootfs" and not by
	# 	    its true device name so this would break. If the rootfs is mounted on two places
	#	    during boot, it confuses the heck out of fsck. So Im auto-adding the root-partition
	#	    to /etc/udev/mount.blacklist via postinst 

        DEV_NOT_MOUNTED=`cat /proc/mounts | awk '{print $1}' | \
                        grep -q "^$DEVNAME$"; echo $?`         
                                                                                
        IS_FLASH=`echo $DEVNAME | grep "mmc" 1>/dev/null;echo $?`

        if [ $DEV_NOT_MOUNTED -ne 0 ]                                  
        then
          if [ $IS_FLASH -ne 0 ] 
          then
            mount_flash
            source /tmp/user/dbus.env 
            su -c "dbus-send --type=signal / b5.flash.inserted \
            string:$name " user
          fi
        fi
fi



if [ "$ACTION" = "remove" ] && [ -x "$UMOUNT" ] && [ -n "$DEVNAME" ]; then
	for mnt in `cat /proc/mounts | grep "$DEVNAME" | cut -f 2 -d " " `
	do
		$UMOUNT -l $mnt
	done
	
	# Remove empty directories from auto-mounter
	test -e "/tmp/.automount-$name" && rm_dir "/media/$name"

        IS_FLASH=`echo $DEVNAME | grep "mmc" 1>/dev/null;echo $?`               

        if [ $IS_FLASH -ne 0 ]                                                
        then 
          source /tmp/user/dbus.env 
          su -c "dbus-send --type=signal / b5.flash.removed string:$name " user
        fi
fi

