#!/bin/sh
SLOT=""
CARDTYPE=""
SLOTNAME=""

case $1 in
  "0"|"left")
    SLOT="0"
    SLOTNAME="левом"
    ;;
  "1"|"right")
    SLOT="1"
    SLOTNAME="правом"
    ;;
esac

if [ -z $SLOT ];then
  echo "Неверный номер разъема. Допустимые: 0 или 1!"
  exit 1
fi

CARD_STATE=`cat /sys/devices/platform/pmmcu.0/card$SLOT | grep state | awk '{print $2}'`

if [ $CARD_STATE != "inserted" ]; then
  echo "Невозможно определить состояние модуля в $SLOTNAME разъеме. \
        Проверьте, подключен ли он."
  exit 2
fi

PRODUCTID=`grep -A 2 -e "Port=0$SLOT" /proc/bus/usb/devices | grep -e '^P: *Vendor=03eb'|sed 's/ /\n/g'|grep ProdID| awk -F= '{print $2}'`

case $PRODUCTID in
  "6124")
    CARDTYPE="e1"
    ;;
  "6128")
    CARDTYPE="da"
    ;;
  "6127")
    CARDTYPE="otdr"
    ;;
  "6125")
    CARDTYPE="gbe"
    ;;
esac

if [ -z $CARDTYPE ]; then
  if [ -z $2 ]; then
    echo "Неизвестный тип измерительного модуля. Невозможно обновить!"
    exit 3
  else
    CARDTYPE=$2
  fi
fi

MCU=`ls /lib/firmware/exp-${CARDTYPE}*.bin 2> /dev/null  | awk '{print $1}'`
FPGA=`ls /lib/firmware/exp-${CARDTYPE}*.rbf 2> /dev/null | awk '{print $1}'`

if [ -z $MCU ]; then
  echo "Нет подходящего ПО MCU."
  exit 4
fi

if [ -z $FPGA ]; then
  echo "Нет подходящего ПО FPGA."
  exit 5
fi

MCU_VER=`echo "$MCU" | awk -F_ '{print $2}' | awk -F.bin '{print $1}'`
FPGA_VER=`echo "$FPGA" | awk -F_ '{print $2}' | awk -F.rbf '{print $1}'`

set -e

echo -e "Начат процесс обновления ПО измерительного модуля \"$CARDTYPE\" \
в $SLOTNAME разъёме\
 \nдо версий: \n\t FPGA : $FPGA_VER \n\t MCU  : $MCU_VER"

echo -e "\nВНИМАНИЕ! Если в процессе обновления ПО измерительного модуля\n\
произойдёт отключение питания прибора или извлечение модуля \nиз разъёма, \
существующее ПО будет ПОВРЕЖДЕНО! \n\n\
Пожалуйста, дождитесь появления кнопки \"Готово\"!\n\n"

sleep 2

/usr/bin/flash_card $SLOT $MCU $FPGA

exit 0
